@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '1.13_14';
+our $VERSION = '1.14_01';
 
 use base qw/Class::Accessor::Fast/;
 
@@ -16,7 +16,7 @@ use Shipwright::Backend;
 use Shipwright::Source;
 use Shipwright::Build;
 use File::Temp qw/tempdir/;
-use File::Spec::Functions qw/catfile catdir/;
+use File::Spec::Functions qw/catfile/;
 
 sub new {
     my $class = shift;
