@@ -45,7 +45,7 @@ sub new {
 
 sub _subclass_method {
     my $method = ( caller(0) )[3];
-    die "your should subclass $method\n";
+    confess "your should subclass $method\n";
 }
 
 =item initialize
@@ -62,15 +62,15 @@ sub initialize {
     dircopy( Shipwright::Util->share_root, $dir );
 
     # copy YAML/Tiny.pm to inc/
-    my $yaml_tiny_path = catfile( $dir, 'inc', 'YAML' );
+    my $yaml_tiny_path = catdir( $dir, 'inc', 'YAML' );
     mkpath $yaml_tiny_path;
     require Module::Info;
     copy( Module::Info->new_from_module('YAML::Tiny')->file, $yaml_tiny_path )
-      or die "copy YAML/Tiny.pm failed: $!";
+      or confess "copy YAML/Tiny.pm failed: $!";
 
     # share_root can't keep empty dirs, we have to create them manually
     for (qw/dists scripts t/) {
-        mkdir catfile( $dir, $_ );
+        mkdir catdir( $dir, $_ );
     }
 
     # hack for share_root living under blib/
@@ -238,7 +238,7 @@ sub update_order {
     my $source = Algorithm::Dependency::Source::HoA->new($require);
     $source->load();
     my $dep = Algorithm::Dependency::Ordered->new( source => $source, )
-      or die $@;
+      or confess $@;
     my $order = $dep->schedule_all();
 
     $order = $self->fiddle_order($order);
@@ -279,6 +279,7 @@ sub fiddle_order {
         if ( grep { $_ eq $maker } @$order ) {
             @$order = grep { $_ ne $maker } @$order;
             my $first_cpan_index = firstidx { /^cpan-/ } @$order;
+            $first_cpan_index = scalar @$order if $first_cpan_index == -1;
             splice @$order, $first_cpan_index, 0, $maker;
 
             if ( $maker eq 'cpan-Module-Build' ) {
