@@ -50,20 +50,20 @@ sub new {
     no warnings 'uninitialized';
 
     $ENV{DYLD_LIBRARY_PATH} =
-      catfile( $self->install_base, 'lib' ) . ':' . $ENV{DYLD_LIBRARY_PATH};
+      catdir( $self->install_base, 'lib' ) . ':' . $ENV{DYLD_LIBRARY_PATH};
     $ENV{LD_LIBRARY_PATH} =
-      catfile( $self->install_base, 'lib' ) . ':' . $ENV{LD_LIBRARY_PATH};
+      catdir( $self->install_base, 'lib' ) . ':' . $ENV{LD_LIBRARY_PATH};
     $ENV{PERL5LIB} =
-        catfile( $self->install_base, 'lib', 'perl5', 'site_perl' ) . ':'
-      . catfile( $self->install_base, 'lib', 'perl5' ) . ':'
+        catdir( $self->install_base, 'lib', 'perl5', 'site_perl' ) . ':'
+      . catdir( $self->install_base, 'lib', 'perl5' ) . ':'
       . $ENV{PERL5LIB};
     $ENV{PATH} =
-        catfile( $self->install_base, 'bin' ) . ':'
-      . catfile( $self->install_base, 'sbin' ) . ':'
+        catdir( $self->install_base, 'bin' ) . ':'
+      . catdir( $self->install_base, 'sbin' ) . ':'
       . $ENV{PATH};
     $ENV{PERL_MM_USE_DEFAULT} = 1;
-    $ENV{LDFLAGS} .= ' -L' . catfile( $self->install_base, 'lib' );
-    $ENV{CFLAGS}  .= ' -I' . catfile( $self->install_base, 'include' );
+    $ENV{LDFLAGS} .= ' -L' . catdir( $self->install_base, 'lib' );
+    $ENV{CFLAGS}  .= ' -I' . catdir( $self->install_base, 'include' );
 
     require CPAN;
     require Module::Info;
@@ -104,7 +104,7 @@ sub run {
         $self->test;
     }
     else {
-        dircopy( 'etc', catfile( $self->install_base, 'etc' ) );
+        dircopy( 'etc', catdir( $self->install_base, 'etc' ) );
 
         my $installed_hash = {};
         $installed_file = catfile( $self->install_base, 'installed.yml' );
@@ -203,7 +203,7 @@ sub _install {
     my $dir  = shift;
     my $ktf  = shift;
 
-    chdir catfile( 'dists', $dir );
+    chdir catdir( 'dists', $dir );
 
     if ( -e catfile( '..', '..', 'scripts', $dir, 'build.pl' ) ) {
         $self->log->info(
@@ -239,7 +239,6 @@ sub _install {
                 $cmd  = $_;
             }
 
-            next if $type eq 'clean';        # don't need to clean when install
             if ( $self->skip_test && $type eq 'test' ) {
                 $self->log->info("skip build $type part in $dir");
                 next;
@@ -264,7 +263,12 @@ sub _install {
                         next;
                     }
                 }
-                die "install failed";
+
+                if ( $type ne 'clean' ) {
+
+                    # clean is trivial, we'll just ignore if 'clean' fails
+                    confess "build $dir $type part with failure.";
+                }
             }
         }
     }
@@ -287,8 +291,8 @@ sub _wrapper {
         }
 
         my $dir = ( splitdir($File::Find::dir) )[-1];
-        mkdir catfile( $self->install_base,       "$dir-wrapped" )
-          unless -d catfile( $self->install_base, "$dir-wrapped" );
+        mkdir catdir( $self->install_base,       "$dir-wrapped" )
+          unless -d catdir( $self->install_base, "$dir-wrapped" );
 
         if ( -e catfile( $self->install_base, "$dir-wrapped", $file ) ) {
             $self->log->warn( 'found old '
@@ -300,7 +304,7 @@ sub _wrapper {
 
         my $type;
         if ( -T $file ) {
-            open my $fh, '<', $file or die "can't open $file: $!";
+            open my $fh, '<', $file or confess "can't open $file: $!";
             my $shebang = <$fh>;
             my $base    = quotemeta $self->install_base;
             my $perl    = quotemeta $self->perl;
@@ -318,8 +322,8 @@ sub _wrapper {
             }
         }
 
-        move( $file => catfile( $self->install_base, "$dir-wrapped" ) )
-          or die $!;
+        move( $file => catdir( $self->install_base, "$dir-wrapped" ) )
+          or confess $!;
 
     # if we have this $type(e.g. perl) installed and have that specific wrapper,
     # then link to it, else link to the normal one
@@ -328,18 +332,18 @@ sub _wrapper {
             && -e catfile( '..', 'etc', "shipwright-$type-wrapper" ) )
         {
             symlink catfile( '..', 'etc', "shipwright-$type-wrapper" ) => $file
-              or die $!;
+              or confess $!;
         }
         else {
 
             symlink catfile( '..', 'etc', 'shipwright-script-wrapper' ) => $file
-              or die $!;
+              or confess $!;
         }
     };
 
     my @dirs =
       grep { -d $_ }
-      map { catfile( $self->install_base, $_ ) } qw/bin sbin/;
+      map { catdir( $self->install_base, $_ ) } qw/bin sbin/;
     find( $sub, @dirs ) if @dirs;
 }
 
@@ -389,7 +393,7 @@ sub test {
         $self->log->info("run tests $type:");
         if ( system($cmd) ) {
             $self->log->error("tests failed");
-            die;
+            confess;
         }
     }
 }
