@@ -7,14 +7,13 @@ use Carp;
 use base qw/App::CLI::Command Shipwright::Script/;
 
 use Shipwright;
-use File::Spec::Functions qw/catfile catdir/;
 use Shipwright::Util;
 
 sub run {
     my $self = shift;
     my $name = shift;
 
-    die "need name arg\n" unless $name;
+    confess "need name arg\n" unless $name;
 
     my $shipwright = Shipwright->new( repository => $self->repository, );
     my $map = $shipwright->backend->map || {};
