@@ -61,7 +61,7 @@ sub run {
 
     }
 
-    die "we need source arg\n" unless $source;
+    confess "we need source arg\n" unless $source;
 
     if ( $self->extra_tests ) {
         $shipwright->backend->import(
@@ -85,7 +85,7 @@ sub run {
                 $self->name($name);
             }
             if ( $self->name !~ /^[-.\w]+$/ ) {
-                die
+                confess
                   qq{name can only have alphanumeric characters, "." and "-"\n};
             }
         }
@@ -156,7 +156,7 @@ sub run {
                 move(
                     catfile( $source,     '__require.yml' ),
                     catfile( $script_dir, 'require.yml' )
-                ) or die "move __require.yml failed: $!\n";
+                ) or confess "move __require.yml failed: $!\n";
             }
         }
 
@@ -255,7 +255,7 @@ sub _import_req {
                             move(
                                 catfile( $s,          '__require.yml' ),
                                 catfile( $script_dir, 'require.yml' )
-                            ) or die "move $s/__require.yml failed: $!\n";
+                            ) or confess "move $s/__require.yml failed: $!\n";
                         }
 
                         $self->_generate_build( $s, $script_dir, $shipwright );
@@ -344,7 +344,7 @@ sub _generate_build {
         push @commands, 'clean: ';
     }
 
-    open my $fh, '>', catfile( $script_dir, 'build' ) or die $@;
+    open my $fh, '>', catfile( $script_dir, 'build' ) or confess $@;
     print $fh $_, "\n" for @commands;
     close $fh;
 }
@@ -356,7 +356,7 @@ sub _parent_dir {
     my $source = shift;
     my @dirs   = splitdir($source);
     pop @dirs;
-    return catfile(@dirs);
+    return catdir(@dirs);
 }
 
 1;
