@@ -8,7 +8,7 @@ use base qw/App::CLI::Command Class::Accessor::Fast Shipwright::Script/;
 __PACKAGE__->mk_accessors(qw/all follow builder utility version/);
 
 use Shipwright;
-use File::Spec::Functions qw/catfile catdir/;
+use File::Spec::Functions qw/catdir/;
 use Shipwright::Util;
 use File::Copy qw/copy move/;
 use File::Temp qw/tempdir/;
@@ -44,7 +44,7 @@ sub run {
     }
     else {
 
-        die "need name arg\n" unless $name || $self->all;
+        confess "need name arg\n" unless $name || $self->all;
 
         $map    = $shipwright->backend->map    || {};
         $source = $shipwright->backend->source || {};
@@ -121,7 +121,7 @@ sub _update {
             $name = $map->{$name};
         }
         else {
-            die 'invalid name ' . $name . "\n";
+            confess 'invalid name ' . $name . "\n";
         }
 
         $shipwright->source(
@@ -138,7 +138,7 @@ sub _update {
     $version = Shipwright::Util::LoadFile( $shipwright->source->version_path );
 
     $shipwright->backend->import(
-        source    => catfile( $shipwright->source->directory, $name ),
+        source    => catdir( $shipwright->source->directory, $name ),
         comment   => "update $name",
         overwrite => 1,
         version   => $version->{$name},
